summaryrefslogtreecommitdiffstats
path: root/kicker
diff options
context:
space:
mode:
Diffstat (limited to 'kicker')
-rw-r--r--kicker/DESIGN6
-rw-r--r--kicker/applets/clock/Makefile.am2
-rw-r--r--kicker/applets/clock/clock.cpp2
-rw-r--r--kicker/applets/launcher/Makefile.am2
-rw-r--r--kicker/applets/menu/CMakeLists.txt2
-rw-r--r--kicker/applets/minipager/Makefile.am2
-rw-r--r--kicker/applets/naughty/NaughtyProcessMonitor.cpp6
-rw-r--r--kicker/applets/systemtray/Makefile.am2
-rw-r--r--kicker/applets/taskbar/Makefile.am2
-rw-r--r--kicker/extensions/dockbar/CMakeLists.txt2
-rw-r--r--kicker/extensions/kasbar/Makefile.am4
-rw-r--r--kicker/kicker/CMakeLists.txt6
-rw-r--r--kicker/kicker/Makefile.am2
-rw-r--r--kicker/kicker/core/kicker.cpp2
-rw-r--r--kicker/libkicker/kshadowengine.h2
-rw-r--r--kicker/menuext/CMakeLists.txt2
-rw-r--r--kicker/menuext/Makefile.am2
-rw-r--r--kicker/menuext/find/CMakeLists.txt2
-rw-r--r--kicker/menuext/kate/CMakeLists.txt2
-rw-r--r--kicker/menuext/kate/katesessionmenu.cpp2
-rw-r--r--kicker/menuext/kdeprint/CMakeLists.txt6
-rw-r--r--kicker/menuext/kdeprint/Makefile.am12
-rw-r--r--kicker/menuext/kdeprint/print_mnu.cpp26
-rw-r--r--kicker/menuext/kdeprint/print_mnu.h2
-rw-r--r--kicker/menuext/kdeprint/printmenu.desktop2
-rw-r--r--kicker/menuext/konq-profiles/konqy_menu.cpp10
-rw-r--r--kicker/menuext/konsole/konsole_mnu.cpp8
-rw-r--r--kicker/menuext/prefmenu/CMakeLists.txt2
-rw-r--r--kicker/menuext/remote/CMakeLists.txt2
-rw-r--r--kicker/proxy/CMakeLists.txt8
-rw-r--r--kicker/proxy/Makefile.am4
-rw-r--r--kicker/taskmanager/CMakeLists.txt2
32 files changed, 69 insertions, 69 deletions
diff --git a/kicker/DESIGN b/kicker/DESIGN
index ca7fa7b2c..dd66260f0 100644
--- a/kicker/DESIGN
+++ b/kicker/DESIGN
@@ -62,12 +62,12 @@ these files should be moved to kdebase/kicker/kcm
(... add docu here about the structure of the kcm stuff and how it uses
DCOP to communicate with the panels ...)
-In kdelibs/kdeui there are two classes that are quite important to kicker.
+In kdelibs/tdeui there are two classes that are quite important to kicker.
The first is KPanelApplet, which is the base class of all kicker applets.
The other class is KPanelExtension, which is the base class of all kicker
extensions.
-These classes are in kdeui so that other applications besides kicker may
+These classes are in tdeui so that other applications besides kicker may
use these facilities, either to provide their own applet/extension
facilities or so as to provide kicker applets/extensions. This strategy
should be re-examined in KDE4 and the APIs of both classes cleaned up
@@ -77,7 +77,7 @@ extensively.
---------------------
applets/
The basic set of applets. Everything here subclasses from KPanelApplet found
-in kdelibs/kdeui. These can be assumed to exist at startup and are allowed,
+in kdelibs/tdeui. These can be assumed to exist at startup and are allowed,
if not encouraged to, access kicker internals.
buttons/
diff --git a/kicker/applets/clock/Makefile.am b/kicker/applets/clock/Makefile.am
index b87e0d8e7..aab460112 100644
--- a/kicker/applets/clock/Makefile.am
+++ b/kicker/applets/clock/Makefile.am
@@ -19,7 +19,7 @@ clock_panelapplet_la_LDFLAGS = -module $(KDE_PLUGIN) $(all_libraries)
clock_panelapplet_la_LIBADD = ../../libkicker/libkickermain.la $(LIB_KDEUI)
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/clockapplet clockapplet *.h -lqt -lkdecore -lkdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/clockapplet clockapplet *.h -lqt -ltdecore -ltdeui -lkfile
messages: rc.cpp
$(XGETTEXT) *.cpp *.h -o $(podir)/clockapplet.pot
diff --git a/kicker/applets/clock/clock.cpp b/kicker/applets/clock/clock.cpp
index 6eb40993d..74e6a6c99 100644
--- a/kicker/applets/clock/clock.cpp
+++ b/kicker/applets/clock/clock.cpp
@@ -1515,7 +1515,7 @@ void ClockApplet::contextMenuActivated(int result)
preferences();
break;
case 103:
- proc << locate("exe", "kdesu");
+ proc << locate("exe", "tdesu");
proc << "--nonewdcop";
proc << TQString("%1 kde-clock.desktop --lang %2")
.arg(locate("exe", "kcmshell"))
diff --git a/kicker/applets/launcher/Makefile.am b/kicker/applets/launcher/Makefile.am
index a101c6ccf..cc06542b5 100644
--- a/kicker/applets/launcher/Makefile.am
+++ b/kicker/applets/launcher/Makefile.am
@@ -24,4 +24,4 @@ messages: rc.cpp
$(XGETTEXT) *.cpp *.h -o $(podir)/quicklauncher.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/quicklauncher quicklauncher *.h -lqt -lkdecore -lkdeui
+ kdoc -a -p -H -d $$HOME/web/src/quicklauncher quicklauncher *.h -lqt -ltdecore -ltdeui
diff --git a/kicker/applets/menu/CMakeLists.txt b/kicker/applets/menu/CMakeLists.txt
index b0accd9a7..772348e3a 100644
--- a/kicker/applets/menu/CMakeLists.txt
+++ b/kicker/applets/menu/CMakeLists.txt
@@ -28,6 +28,6 @@ install( FILES menuapplet.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/applets
tde_add_kpart( menu_panelapplet AUTOMOC
SOURCES menuapplet.cpp menuapplet.skel
- LINK kdeui-shared
+ LINK tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/applets/minipager/Makefile.am b/kicker/applets/minipager/Makefile.am
index da149f468..d84f1993c 100644
--- a/kicker/applets/minipager/Makefile.am
+++ b/kicker/applets/minipager/Makefile.am
@@ -22,4 +22,4 @@ messages: rc.cpp
$(XGETTEXT) *.cpp *.h -o $(podir)/kminipagerapplet.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/kminipagerapplet kminipagerapplet *.h -lqt -lkdecore -lkdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/kminipagerapplet kminipagerapplet *.h -lqt -ltdecore -ltdeui -lkfile
diff --git a/kicker/applets/systemtray/Makefile.am b/kicker/applets/systemtray/Makefile.am
index 849795a9e..33a0be11c 100644
--- a/kicker/applets/systemtray/Makefile.am
+++ b/kicker/applets/systemtray/Makefile.am
@@ -21,4 +21,4 @@ messages:
$(XGETTEXT) *.cpp *.h -o $(podir)/ksystemtrayapplet.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/ksystemtrayapplet ksystemtrayapplet *.h -lqt -lkdecore -lkdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/ksystemtrayapplet ksystemtrayapplet *.h -lqt -ltdecore -ltdeui -lkfile
diff --git a/kicker/applets/taskbar/Makefile.am b/kicker/applets/taskbar/Makefile.am
index 35cb337e6..700cf27d8 100644
--- a/kicker/applets/taskbar/Makefile.am
+++ b/kicker/applets/taskbar/Makefile.am
@@ -19,4 +19,4 @@ messages:
$(XGETTEXT) *.cpp *.h -o $(podir)/ktaskbarapplet.pot
srcdoc:
- kdoc -a -p -H -d $$HOME/web/src/ktaskbarapplet ktaskbarapplet *.h -lqt -lkdecore -lkdeui -lkfile
+ kdoc -a -p -H -d $$HOME/web/src/ktaskbarapplet ktaskbarapplet *.h -lqt -ltdecore -ltdeui -lkfile
diff --git a/kicker/extensions/dockbar/CMakeLists.txt b/kicker/extensions/dockbar/CMakeLists.txt
index 3fb274a80..9758f527c 100644
--- a/kicker/extensions/dockbar/CMakeLists.txt
+++ b/kicker/extensions/dockbar/CMakeLists.txt
@@ -35,6 +35,6 @@ set( ${target}_SRCS
tde_add_kpart( ${target} AUTOMOC
SOURCES ${${target}_SRCS}
- LINK kdeui-shared
+ LINK tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/extensions/kasbar/Makefile.am b/kicker/extensions/kasbar/Makefile.am
index 247837a6d..2209e3335 100644
--- a/kicker/extensions/kasbar/Makefile.am
+++ b/kicker/extensions/kasbar/Makefile.am
@@ -37,7 +37,7 @@ EXTRA_DIST = $(lnk_DATA)
bin_PROGRAMS = kasbar
kasbar_SOURCES = kasbarapp.cpp
-kasbar_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+kasbar_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
kasbar_LDADD = libkasbar.la \
$(LIB_QT) $(LIB_KDECORE) $(LIB_KDEUI)
@@ -46,7 +46,7 @@ messages:
$(XGETTEXT) *.cpp *.h -o $(podir)/kasbarextension.pot
srcdoc:
- $(kde_bindir)/kdoc -a -p -d classdocs -n 'Kasbar2' ../../taskmanager/*.h *.h -lqt -lkdecore -lkdeui
+ $(kde_bindir)/kdoc -a -p -d classdocs -n 'Kasbar2' ../../taskmanager/*.h *.h -lqt -ltdecore -ltdeui
.PHONY: changes
changes:
diff --git a/kicker/kicker/CMakeLists.txt b/kicker/kicker/CMakeLists.txt
index dc5053d5a..5ec37ac53 100644
--- a/kicker/kicker/CMakeLists.txt
+++ b/kicker/kicker/CMakeLists.txt
@@ -42,16 +42,16 @@ install( PROGRAMS
tde_add_executable( kicker-3.4-reverseLayout
SOURCES kicker-3.4-reverseLayout.cpp
- LINK kdecore-shared
+ LINK tdecore-shared
DESTINATION ${LIB_INSTALL_DIR}/kconf_update_bin
)
-##### kicker (kdeinit) ##########################
+##### kicker (tdeinit) ##########################
configure_file( ${CMAKE_SOURCE_DIR}/cmake/modules/template_dummy_cpp.cmake dummy.cpp COPYONLY )
-tde_add_kdeinit_executable( kicker
+tde_add_tdeinit_executable( kicker
SOURCES dummy.cpp
EMBED kicker_core-static
LINK kicker_buttons-static kicker_ui-static kickermain-shared kabc-shared kutils-shared
diff --git a/kicker/kicker/Makefile.am b/kicker/kicker/Makefile.am
index 9a89a0ac0..b1a037275 100644
--- a/kicker/kicker/Makefile.am
+++ b/kicker/kicker/Makefile.am
@@ -5,7 +5,7 @@ SUBDIRS = core interfaces ui buttons .
bin_PROGRAMS =
lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = kicker.la
+tdeinit_LTLIBRARIES = kicker.la
CLEANFILES = dummy.cpp
diff --git a/kicker/kicker/core/kicker.cpp b/kicker/kicker/core/kicker.cpp
index ce7de00c0..7ba06c61c 100644
--- a/kicker/kicker/core/kicker.cpp
+++ b/kicker/kicker/core/kicker.cpp
@@ -270,7 +270,7 @@ void Kicker::slotRestart()
char ** o_argv = new char*[2];
o_argv[0] = strdup("kicker");
o_argv[1] = 0L;
- execv(TQFile::encodeName(locate("exe", "kdeinit_wrapper")), o_argv);
+ execv(TQFile::encodeName(locate("exe", "tdeinit_wrapper")), o_argv);
exit(1);
}
diff --git a/kicker/libkicker/kshadowengine.h b/kicker/libkicker/kshadowengine.h
index 0c44e1816..1ddc093ff 100644
--- a/kicker/libkicker/kshadowengine.h
+++ b/kicker/libkicker/kshadowengine.h
@@ -82,7 +82,7 @@ public:
TQImage makeShadow(const TQPixmap& textPixmap, const TQColor &bgColor);
private:
- // No static objects in libs, and no static deleters in kdefx...
+ // No static objects in libs, and no static deleters in tdefx...
//static KShadowSettings s_defaultShadowSettings;
KShadowSettings *m_shadowSettings;
diff --git a/kicker/menuext/CMakeLists.txt b/kicker/menuext/CMakeLists.txt
index 2d214e656..ca6eb3766 100644
--- a/kicker/menuext/CMakeLists.txt
+++ b/kicker/menuext/CMakeLists.txt
@@ -10,7 +10,7 @@
#################################################
add_subdirectory( find )
-add_subdirectory( kdeprint )
+add_subdirectory( tdeprint )
add_subdirectory( prefmenu )
add_subdirectory( recentdocs )
add_subdirectory( konsole )
diff --git a/kicker/menuext/Makefile.am b/kicker/menuext/Makefile.am
index 6d672d29a..31254dff7 100644
--- a/kicker/menuext/Makefile.am
+++ b/kicker/menuext/Makefile.am
@@ -1,2 +1,2 @@
-SUBDIRS = find kdeprint prefmenu recentdocs konsole konq-profiles remote system kate
+SUBDIRS = find tdeprint prefmenu recentdocs konsole konq-profiles remote system kate
diff --git a/kicker/menuext/find/CMakeLists.txt b/kicker/menuext/find/CMakeLists.txt
index 5769dfc09..d4cf03be0 100644
--- a/kicker/menuext/find/CMakeLists.txt
+++ b/kicker/menuext/find/CMakeLists.txt
@@ -29,6 +29,6 @@ install( FILES kfind.desktop websearch.desktop DESTINATION ${DATA_INSTALL_DIR}/k
tde_add_kpart( kickermenu_find AUTOMOC
SOURCES findmenu.cpp
- LINK kdeui-shared
+ LINK tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/menuext/kate/CMakeLists.txt b/kicker/menuext/kate/CMakeLists.txt
index fee34696e..4afbc89c8 100644
--- a/kicker/menuext/kate/CMakeLists.txt
+++ b/kicker/menuext/kate/CMakeLists.txt
@@ -28,6 +28,6 @@ install( FILES katesessionmenu.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/me
tde_add_kpart( kickermenu_kate AUTOMOC
SOURCES katesessionmenu.cpp
- LINK kdeui-shared
+ LINK tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/menuext/kate/katesessionmenu.cpp b/kicker/menuext/kate/katesessionmenu.cpp
index 7326d8fb0..9b237a703 100644
--- a/kicker/menuext/kate/katesessionmenu.cpp
+++ b/kicker/menuext/kate/katesessionmenu.cpp
@@ -143,7 +143,7 @@ void KateSessionMenu::slotExec( int id )
else if ( id > 2 )
args << m_sessions[ id-3 ];
- kapp->kdeinitExec("kate", args);
+ kapp->tdeinitExec("kate", args);
}
diff --git a/kicker/menuext/kdeprint/CMakeLists.txt b/kicker/menuext/kdeprint/CMakeLists.txt
index b6cc714eb..a013bcf82 100644
--- a/kicker/menuext/kdeprint/CMakeLists.txt
+++ b/kicker/menuext/kdeprint/CMakeLists.txt
@@ -24,10 +24,10 @@ link_directories(
install( FILES printmenu.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/menuext )
-##### kickermenu_kdeprint (module) ##############
+##### kickermenu_tdeprint (module) ##############
-tde_add_kpart( kickermenu_kdeprint AUTOMOC
+tde_add_kpart( kickermenu_tdeprint AUTOMOC
SOURCES print_mnu.cpp
- LINK kdeprint-shared
+ LINK tdeprint-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/menuext/kdeprint/Makefile.am b/kicker/menuext/kdeprint/Makefile.am
index 051c087fb..c8ad7858a 100644
--- a/kicker/menuext/kdeprint/Makefile.am
+++ b/kicker/menuext/kdeprint/Makefile.am
@@ -1,15 +1,15 @@
INCLUDES = $(all_includes)
-kde_module_LTLIBRARIES = kickermenu_kdeprint.la
+kde_module_LTLIBRARIES = kickermenu_tdeprint.la
-kickermenu_kdeprint_la_SOURCES = print_mnu.cpp
-kickermenu_kdeprint_la_LDFLAGS = $(all_libraries) -module -avoid-version
-kickermenu_kdeprint_la_LIBADD = $(LIB_KDEUI) $(LIB_KIO) -lkdeprint
+kickermenu_tdeprint_la_SOURCES = print_mnu.cpp
+kickermenu_tdeprint_la_LDFLAGS = $(all_libraries) -module -avoid-version
+kickermenu_tdeprint_la_LIBADD = $(LIB_KDEUI) $(LIB_KIO) -ltdeprint
-kickermenu_kdeprint_la_METASOURCES = AUTO
+kickermenu_tdeprint_la_METASOURCES = AUTO
desktopmenu_DATA = printmenu.desktop
desktopmenudir = $(kde_datadir)/kicker/menuext
messages:
- $(XGETTEXT) *.cpp -o $(podir)/libkickermenu_kdeprint.pot
+ $(XGETTEXT) *.cpp -o $(podir)/libkickermenu_tdeprint.pot
diff --git a/kicker/menuext/kdeprint/print_mnu.cpp b/kicker/menuext/kdeprint/print_mnu.cpp
index eb2dbd8ab..dee220d80 100644
--- a/kicker/menuext/kdeprint/print_mnu.cpp
+++ b/kicker/menuext/kdeprint/print_mnu.cpp
@@ -27,10 +27,10 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#include <kglobal.h>
#include <kapplication.h>
#include <krun.h>
-#include <kdeprint/kmmanager.h>
+#include <tdeprint/kmmanager.h>
#include <tqregexp.h>
-K_EXPORT_KICKER_MENUEXT(kdeprint, PrintMenu)
+K_EXPORT_KICKER_MENUEXT(tdeprint, PrintMenu)
#define ADD_PRINTER_ID 0
#define KDEPRINT_SETTINGS_ID 1
@@ -43,10 +43,10 @@ K_EXPORT_KICKER_MENUEXT(kdeprint, PrintMenu)
PrintMenu::PrintMenu(TQWidget *parent, const char *name, const TQStringList & /*args*/)
: KPanelMenu("", parent, name)
{
- static bool kdeprintIconsInitialized = false;
- if ( !kdeprintIconsInitialized ) {
- KGlobal::iconLoader()->addAppDir("kdeprint");
- kdeprintIconsInitialized = true;
+ static bool tdeprintIconsInitialized = false;
+ if ( !tdeprintIconsInitialized ) {
+ KGlobal::iconLoader()->addAppDir("tdeprint");
+ tdeprintIconsInitialized = true;
}
}
@@ -65,9 +65,9 @@ void PrintMenu::initialize()
if ((KMManager::self()->printerOperationMask() & KMManager::PrinterCreation) && KMManager::self()->hasManagement())
insertItem(SmallIconSet("wizard"), i18n("Add Printer..."), ADD_PRINTER_ID);
- insertItem(SmallIconSet("kdeprint_configmgr"), i18n("KDE Print Settings"), KDEPRINT_SETTINGS_ID);
+ insertItem(SmallIconSet("tdeprint_configmgr"), i18n("KDE Print Settings"), KDEPRINT_SETTINGS_ID);
if (KMManager::self()->serverOperationMask() & KMManager::ServerConfigure)
- insertItem(SmallIconSet("kdeprint_configsrv"), i18n("Configure Server"), CONFIG_SERVER_ID);
+ insertItem(SmallIconSet("tdeprint_configsrv"), i18n("Configure Server"), CONFIG_SERVER_ID);
insertSeparator();
insertItem(SmallIconSet("kcontrol"), i18n("Print Manager"), PRINT_MANAGER_ID);
insertItem(SmallIconSet("konqueror"), i18n("Print Browser (Konqueror)"), PRINT_BROWSER_ID);
@@ -103,13 +103,13 @@ void PrintMenu::slotExec(int ID)
switch (ID)
{
case ADD_PRINTER_ID:
- kapp->kdeinitExec("kaddprinterwizard");
+ kapp->tdeinitExec("kaddprinterwizard");
break;
case KDEPRINT_SETTINGS_ID:
- kapp->kdeinitExec("kaddprinterwizard", TQStringList("--kdeconfig"));
+ kapp->tdeinitExec("kaddprinterwizard", TQStringList("--kdeconfig"));
break;
case CONFIG_SERVER_ID:
- kapp->kdeinitExec("kaddprinterwizard", TQStringList("--serverconfig"));
+ kapp->tdeinitExec("kaddprinterwizard", TQStringList("--serverconfig"));
break;
case PRINT_MANAGER_ID:
KRun::runCommand("kcmshell kde-printers.desktop");
@@ -118,14 +118,14 @@ void PrintMenu::slotExec(int ID)
KRun::runCommand("kfmclient openProfile filemanagement print:/", "kfmclient", "konqueror");
break;
case KPRINTER_ID:
- kapp->kdeinitExec("kprinter");
+ kapp->tdeinitExec("kprinter");
break;
default:
{
// start kjobviewer
TQStringList args;
args << "--show" << "-d" << text(ID).remove('&');
- kapp->kdeinitExec("kjobviewer", args);
+ kapp->tdeinitExec("kjobviewer", args);
}
break;
}
diff --git a/kicker/menuext/kdeprint/print_mnu.h b/kicker/menuext/kdeprint/print_mnu.h
index da795c039..47c9e609e 100644
--- a/kicker/menuext/kdeprint/print_mnu.h
+++ b/kicker/menuext/kdeprint/print_mnu.h
@@ -25,7 +25,7 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#define _print_mnu_h_
#include <kpanelmenu.h>
-#include <kdeprint/kpreloadobject.h>
+#include <tdeprint/kpreloadobject.h>
class PrintMenu : public KPanelMenu, public KPReloadObject
{
diff --git a/kicker/menuext/kdeprint/printmenu.desktop b/kicker/menuext/kdeprint/printmenu.desktop
index 2bc90f1b8..447d62c8f 100644
--- a/kicker/menuext/kdeprint/printmenu.desktop
+++ b/kicker/menuext/kdeprint/printmenu.desktop
@@ -141,4 +141,4 @@ Comment[zh_CN]=打印系统菜单
Comment[zh_TW]=用於列印系統的選單
Icon=fileprint
-X-KDE-Library=kickermenu_kdeprint
+X-KDE-Library=kickermenu_tdeprint
diff --git a/kicker/menuext/konq-profiles/konqy_menu.cpp b/kicker/menuext/konq-profiles/konqy_menu.cpp
index 4010bace7..cb340caf9 100644
--- a/kicker/menuext/konq-profiles/konqy_menu.cpp
+++ b/kicker/menuext/konq-profiles/konqy_menu.cpp
@@ -39,10 +39,10 @@ K_EXPORT_KICKER_MENUEXT(konqueror, KonquerorProfilesMenu)
KonquerorProfilesMenu::KonquerorProfilesMenu(TQWidget *parent, const char *name, const TQStringList & /*args*/)
: KPanelMenu("", parent, name)
{
- static bool kdeprintIconsInitialized = false;
- if ( !kdeprintIconsInitialized ) {
- KGlobal::iconLoader()->addAppDir("kdeprint");
- kdeprintIconsInitialized = true;
+ static bool tdeprintIconsInitialized = false;
+ if ( !tdeprintIconsInitialized ) {
+ KGlobal::iconLoader()->addAppDir("tdeprint");
+ tdeprintIconsInitialized = true;
}
}
@@ -83,7 +83,7 @@ void KonquerorProfilesMenu::slotExec(int id)
{
TQStringList args;
args<<"--profile"<<m_profiles[id-1];
- kapp->kdeinitExec("konqueror", args);
+ kapp->tdeinitExec("konqueror", args);
}
void KonquerorProfilesMenu::reload()
diff --git a/kicker/menuext/konsole/konsole_mnu.cpp b/kicker/menuext/konsole/konsole_mnu.cpp
index be060b75c..e9f1cede1 100644
--- a/kicker/menuext/konsole/konsole_mnu.cpp
+++ b/kicker/menuext/konsole/konsole_mnu.cpp
@@ -258,7 +258,7 @@ void KonsoleMenu::slotExec(int id)
args << "-r";
args << screenList[id - sessionList.count()];
}
- KApplication::kdeinitExec("konsole", args);
+ KApplication::tdeinitExec("konsole", args);
return;
}
@@ -273,7 +273,7 @@ void KonsoleMenu::launchProfile(int id)
// this is a session, not a bookmark, so execute that instead
TQStringList args;
args << "--profile" << m_profiles[id];
- kapp->kdeinitExec("konsole", args);
+ kapp->tdeinitExec("konsole", args);
}
KURL KonsoleMenu::baseURL() const
@@ -292,7 +292,7 @@ void KonsoleMenu::newSession(const TQString& sURL, const TQString& title)
{
args << "-T" << title;
args << "--workdir" << url.path();
- KApplication::kdeinitExec("konsole", args);
+ KApplication::tdeinitExec("konsole", args);
return;
}
else if ((!url.protocol().isEmpty()) && (url.hasHost()))
@@ -305,7 +305,7 @@ void KonsoleMenu::newSession(const TQString& sURL, const TQString& title)
args << "-l" << url.user().latin1();
}
args << host.latin1();
- KApplication::kdeinitExec("konsole", args);
+ KApplication::tdeinitExec("konsole", args);
return;
}
/*
diff --git a/kicker/menuext/prefmenu/CMakeLists.txt b/kicker/menuext/prefmenu/CMakeLists.txt
index 24b947d54..448e03d74 100644
--- a/kicker/menuext/prefmenu/CMakeLists.txt
+++ b/kicker/menuext/prefmenu/CMakeLists.txt
@@ -30,6 +30,6 @@ install( FILES prefmenu.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/menuext )
tde_add_kpart( kickermenu_prefmenu AUTOMOC
SOURCES prefmenu.cpp
- LINK kickermain-shared kdeui-shared
+ LINK kickermain-shared tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/menuext/remote/CMakeLists.txt b/kicker/menuext/remote/CMakeLists.txt
index eae12847b..247b5f01d 100644
--- a/kicker/menuext/remote/CMakeLists.txt
+++ b/kicker/menuext/remote/CMakeLists.txt
@@ -29,6 +29,6 @@ install( FILES remotemenu.desktop DESTINATION ${DATA_INSTALL_DIR}/kicker/menuext
tde_add_kpart( kickermenu_remotemenu AUTOMOC
SOURCES remotemenu.cpp remotemenu.skel
- LINK kickermain-shared kdeui-shared
+ LINK kickermain-shared tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/kicker/proxy/CMakeLists.txt b/kicker/proxy/CMakeLists.txt
index 68c99312d..a637d141e 100644
--- a/kicker/proxy/CMakeLists.txt
+++ b/kicker/proxy/CMakeLists.txt
@@ -25,17 +25,17 @@ link_directories(
install( FILES DESTINATION ${DATA_INSTALL_DIR}/kicker/menuext )
-##### appletproxy (kdeinit) #####################
+##### appletproxy (tdeinit) #####################
-tde_add_kdeinit_executable( appletproxy AUTOMOC
+tde_add_tdeinit_executable( appletproxy AUTOMOC
SOURCES appletproxy.cpp
LINK kickermain-shared
)
-##### extensionproxy (kdeinit) ##################
+##### extensionproxy (tdeinit) ##################
-tde_add_kdeinit_executable( extensionproxy AUTOMOC
+tde_add_tdeinit_executable( extensionproxy AUTOMOC
SOURCES extensionproxy.cpp
LINK kickermain-shared
)
diff --git a/kicker/proxy/Makefile.am b/kicker/proxy/Makefile.am
index 56e4269bb..698a663c1 100644
--- a/kicker/proxy/Makefile.am
+++ b/kicker/proxy/Makefile.am
@@ -3,7 +3,7 @@ INCLUDES = -I$(srcdir)/../libkicker $(all_includes)
bin_PROGRAMS =
noinst_PROGRAMS = extensiondebugger
lib_LTLIBRARIES =
-kdeinit_LTLIBRARIES = appletproxy.la extensionproxy.la
+tdeinit_LTLIBRARIES = appletproxy.la extensionproxy.la
METASOURCES = AUTO
@@ -17,7 +17,7 @@ extensionproxy_la_LDFLAGS = $(all_libraries) $(KDE_RPATH) -module -avoid-version
extensiondebugger_SOURCES = extensiondebugger.cpp
extensiondebugger_LDADD = ../libkicker/libkickermain.la
-extensiondebugger_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -lkdefx $(LIB_KIO) -lktexteditor
+extensiondebugger_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_KDECORE) $(LIB_KDEUI) -ltdefx $(LIB_KIO) -lktexteditor
messages:
$(XGETTEXT) appletproxy.cpp -o $(podir)/appletproxy.pot
diff --git a/kicker/taskmanager/CMakeLists.txt b/kicker/taskmanager/CMakeLists.txt
index a1599f917..852b6d52c 100644
--- a/kicker/taskmanager/CMakeLists.txt
+++ b/kicker/taskmanager/CMakeLists.txt
@@ -53,6 +53,6 @@ set( ${target}_SRCS
tde_add_library( ${target} SHARED AUTOMOC
SOURCES ${${target}_SRCS}
VERSION 1.0.0
- LINK kdecore-shared kickermain-shared ${XFIXES_LIBRARIES} ${XRENDER_LIBRARIES} ${XCOMPOSITE_LIBRARIES}
+ LINK tdecore-shared kickermain-shared ${XFIXES_LIBRARIES} ${XRENDER_LIBRARIES} ${XCOMPOSITE_LIBRARIES}
DESTINATION ${LIB_INSTALL_DIR}
)
diff --git a/kicker/applets/naughty/NaughtyProcessMonitor.cpp b/kicker/applets/naughty/NaughtyProcessMonitor.cpp
index 0a9d5c676..aaca4213e 100644
--- a/kicker/applets/naughty/NaughtyProcessMonitor.cpp
+++ b/kicker/applets/naughty/NaughtyProcessMonitor.cpp
@@ -254,7 +254,7 @@ NaughtyProcessMonitor::processName(ulong pid) const
s += char(c);
}
// Now strip 'kdeinit:' prefix.
TQString tqunicode(TQString::fromLocal8Bit(s));
#elif defined(__OpenBSD__)
@@ -279,7 +279,7 @@ NaughtyProcessMonitor::processName(ulong pid) const
return i18n("Unknown") ;
}
// Now strip 'kdeinit:' prefix.
TQString tqunicode(TQString::fromLocal8Bit(argv[0]));
free (argv) ;
@@ -287,7 +287,7 @@ NaughtyProcessMonitor::processName(ulong pid) const
TQStringList parts(TQStringList::split(' ', tqunicode));
- TQString processName = parts[0] == "kdeinit:" ? parts[1] : parts[0];
+ TQString processName = parts[0] == "tdeinit:" ? parts[1] : parts[0];
int lastSlash = processName.findRev('/');
@@ -254,7 +254,7 @@ NaughtyProcessMonitor::processName(ulong pid) const
s += char(c);
}
- // Now strip 'kdeinit:' prefix.
+ // Now strip 'tdeinit:' prefix.
TQString tqunicode(TQString::fromLocal8Bit(s));
#elif defined(__OpenBSD__)
@@ -279,7 +279,7 @@ NaughtyProcessMonitor::processName(ulong pid) const
return i18n("Unknown") ;
}
- // Now strip 'kdeinit:' prefix.
+ // Now strip 'tdeinit:' prefix.
TQString tqunicode(TQString::fromLocal8Bit(argv[0]));
free (argv) ;